==> unit-1.1.25-sources.jar: io/intino/goros/unit/box/rest/resources/PostUnlockTaskResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.spark.SparkManager;
import io.intino.alexandria.http.spark.SparkPushService;

import io.intino.goros.unit.box.schemas.*;

public class PostUnlockTaskResource implements Resource {

	private UnitBox box;
	private SparkManager<SparkPushService> manager;

	public PostUnlockTaskResource(UnitBox box, SparkManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.PostUnlockTaskAction()).execute());
	}

	private io.intino.goros.unit.box.actions.PostUnlockTaskAction fill(io.intino.goros.unit.box.actions.PostUnlockTaskAction action) throws AlexandriaException {
		action.box = this.box;
		action.context = context();
		try {
			action.id = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("id"), String.class);
			action.place = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("place"), String.class);
			action.stop = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("stop"), String.class);
		} catch (Throwable e) {
			action.onMalformedRequest(e);
		}
		return action;
	}

	private void write(String object) {
		manager.write(io.intino.alexandria.rest.ResponseAdapter.adapt(object));
	}

	private io.intino.alexandria.http.spark.SparkContext context() {
		io.intino.alexandria.http.spark.SparkContext context = new io.intino.alexandria.http.spark.SparkContext(manager);

		context.put("ip", manager.ip());
		return context;
	}
}

==> unit-2.1.5-sources.jar: io/intino/goros/unit/box/rest/resources/PostUnlockTaskResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.Set;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.server.AlexandriaHttpManager;
import io.intino.alexandria.http.pushservice.PushService;

import io.intino.goros.unit.box.schemas.*;

public class PostUnlockTaskResource implements Resource {

	private UnitBox box;
	private AlexandriaHttpManager<PushService<?,?>> manager;

	public PostUnlockTaskResource(UnitBox box, AlexandriaHttpManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.PostUnlockTaskAction()).execute());
	}

	private io.intino.goros.unit.box.actions.PostUnlockTaskAction fill(io.intino.goros.unit.box.actions.PostUnlockTaskAction action) throws AlexandriaException {
		action.box = this.box;
		action.context = context();
		try {
			action.id = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("id"), String.class);
			action.place = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("place"), String.class);
			action.stop = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("stop"), String.class);
		} catch (Throwable e) {
			action.onMalformedRequest(e);
		}
		return action;
	}

	private void write(String object) {
		manager.write(io.intino.alexandria.rest.ResponseAdapter.adapt(object));
	}

	private io.intino.alexandria.http.server.AlexandriaHttpContext context() {
		io.intino.alexandria.http.server.AlexandriaHttpContext context = new io.intino.alexandria.http.server.AlexandriaHttpContext(manager);

		context.put("pathInfo", manager.request().raw().getPathInfo());
		context.put("ip", manager.ip());
		return context;
	}
}
